<?php

namespace App\Http\Controllers;

use App\Imports\DataKecamatanImport;
use App\Models\Kabupaten;
use Illuminate\Http\Request;
use App\Models\Kecamatan;
use App\Models\UserLog;
// use Auth;
use Illuminate\Support\Facades\Auth;
use Exception;
use Illuminate\Support\Facades\Session;
use Maatwebsite\Excel\Facades\Excel;

class KecamatanController extends Controller
{


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = "Kecamatan";
        $link = "kecamatan";
        $parent = "Master Data";

        $s = '';
        $page = 1;

        if(isset($_GET['s'])){
            $s = $_GET['s'];
        }

        if(isset($_GET['page'])){
            $page = $_GET['page'];
        }

        $datas = Kecamatan::with('kelurahans')->where('nama_kecamatan','like','%'.$s.'%')->orderBy('created_at','DESC')->paginate(10);
        $datas->appends($_GET);
        $no = 1*$page*10-10+1;
        // return view('kecamatan.index',compact('title','kecamatan','parent','link','datas','no'));
        return view('kecamatan.index',compact('title','parent','link','datas','no'));

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $title = "Tambah Data Kecamatan";
        $link = "kecamatan";
        $parent = "Kecamatan";
        $kabupatens = Kabupaten::orderBy('nama_kabupaten','ASC')->pluck('nama_kabupaten','id');
        // return view('kecamatan.create',compact('title','kecamatan','parent','link'));
        return view('kecamatan.create',compact('title','parent','link', 'kabupatens'));

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            $request->validate([
                'nama_kecamatan' => 'required|unique:kecamatans|max:255|string',
            ]);
            $data = new Kecamatan;
            $data->nama_kecamatan = $request->nama_kecamatan;
            $data->kabupaten_id = $request->kabupaten_id;
            $data->save();
            $msg = 'Berhasil menambah data kecamatan '.$data->nama_kecamatan;
            UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
            return redirect('kecamatan')->with('success_message', $msg);
        } catch (Exception $e) {
            return redirect('kecamatan')->with('error_message', "Gagal di tambah");
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $title = "Edit Data Kecamatan";
        $link = "kecamatan";
        $parent = "Kecamatan";
        $data = Kecamatan::find($id);
        $kabupatens = Kabupaten::orderBy('nama_kabupaten','ASC')->pluck('nama_kabupaten','id');
        // return view('kecamatan.edit',compact('title','kecamatan','parent','link','data'));
        return view('kecamatan.edit',compact('title','parent','link','data', 'kabupatens'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = Kecamatan::find($id);
        $data->nama_kecamatan = $request->nama_kecamatan;
        $data->kabupaten_id = $request->kabupaten_id;
        $data->save();
        $msg = 'Berhasil mengubah data kecamatan '.$data->nama_kecamatan;
        UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
        return redirect('kecamatan')->with('success_message', $msg);
    }

    public function importView()
    {
        // dd("Test");
        $title = "Import Data Kecamatan";
        $link = "kecamatan";
        $parent = "Data Kecamatan";
        $warnings = Session::get('alert_import',[]);

        return view('kecamatan.import',compact('title','parent','link','warnings'));
    }

    public function import(Request $request)
    {
        Session::put('alert_import',[]);

        Excel::import(new DataKecamatanImport,request()->file('file'));
        $msg = 'Berhasil mengimport data excel dengan nama '.$request->file->getClientOriginalName();
        UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
        return redirect('kecamatan/import')->with('success_message', $msg);

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        try {
            $data = Kecamatan::find($id);
            if(count($data->kelurahans) > 0){
                return redirect('kecamatan')->with('error_message', "Data tidak bisa di hapus.masih ada kelurahan yang menggunakan kecamatan ini");
            }
            $data->delete();
            $msg = 'Berhasil menghapus data kecamatan '.$data->nama_kelurahan;
            UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
            return redirect('kecamatan')->with('success_message', $msg);
        } catch (Exception $e) {
            return redirect('kecamatan')->with('error_message', "Gagal dihapus");
        }
    }
}
